@@ -1,14 +1,16 @@
 #' Convert KFAS Model to bssm Model
 #'
-#' Converts \code{SSModel} object of \code{KFAS} package to general
-#' \code{bssm} model of type \code{ssm_ulg}, \code{ssm_mlg}, \code{ssm_ung} or \code{ssm_mng}.
+#' Converts \code{SSModel} object of \code{KFAS} package to general \code{bssm} 
+#' model of type \code{ssm_ulg}, \code{ssm_mlg}, \code{ssm_ung} or 
+#' \code{ssm_mng}.
 #' 
 #' @param model Object of class \code{SSModel}.
 #' @param kappa For \code{SSModel} object, a prior variance for initial state
 #' used to replace exact diffuse elements of the original model.
 #' @param ... Additional arguments to model building functions of \code{bssm}
 #' (such as prior and updating functions).
-#' @return Object of class \code{ssm_ulg}, \code{ssm_mlg}, \code{ssm_ung} or \code{ssm_mng}.
+#' @return Object of class \code{ssm_ulg}, \code{ssm_mlg}, \code{ssm_ung} or 
+#' \code{ssm_mng}.
 #' @export
 #' @examples
 #' library("KFAS")
@@ -46,17 +48,19 @@ as_bssm <- function(model, kappa = 100, ...) {
     Z <- aperm(model$Z, c(2, 3, 1))
     dim(Z) <- dim(Z)[1:2]
   } else {
-    Z = model$Z
+    Z <- model$Z
   }
   
   if (any(model$distribution != "gaussian")) {
     if (attr(model, "p") == 1) {
-      
-      if (model$distribution == "negative binomial" && length(unique(model$u)) > 1) {
-        stop("Time-varying dispersion parameter for negative binomial is not (yet) supported in 'bssm'.")
+      if (model$distribution == "negative binomial" && 
+          length(unique(model$u)) > 1) {
+        stop(paste("Time-varying dispersion parameter for negative binomial",
+        "is not (yet) supported in 'bssm'.", sep = " "))
       } 
       if (model$distribution == "gamma" && length(unique(model$u)) > 1) {
-        stop("Time-varying shape parameter for gamma is not (yet) supported in 'bssm'.")
+        stop(paste("Time-varying shape parameter for gamma is not (yet)",
+        "supported in 'bssm'.", sep = " "))
       }
       
       switch(model$distribution,
@@ -83,33 +87,37 @@ as_bssm <- function(model, kappa = 100, ...) {
     } else {
       phi <- numeric(attr(model, "p"))
       u <- model$u
-      for(i in 1:attr(model, "p")) {
+      for (i in 1:attr(model, "p")) {
         switch(model$distribution[i],
           poisson = {
             phi[i] <- 1
-            u[,i] <- model$u[,i]
+            u[, i] <- model$u[, i]
           },
           binomial = {
             phi[i] <- 1
-            u[,i] <- model$u[,i]
+            u[, i] <- model$u[, i]
           },
           gamma = {
-            if(length(unique(model$u[,i])) > 1)
-              stop("Time-varying shape parameter for gamma is not (yet) supported in 'bssm'.")
-            phi[i] <- model$u[1,i]
-            u[,i] <- 1 # no exposure for Gamma in KFAS
+            if (length(unique(model$u[, i])) > 1)
+              stop(paste0("Time-varying shape parameter for gamma is not",
+              "(yet) supported in 'bssm'.", sep = " "))
+            phi[i] <- model$u[1, i]
+            u[, i] <- 1 # no exposure for Gamma in KFAS
           },
           "negative binomial" = {
-            if(length(unique(model$u[,i])) > 1)
-              stop("Time-varying dispersion parameter for negative binomial is not (yet) supported in 'bssm'.")
-            phi[i] <- model$u[1,i]
-            u[,i] <- 1 # no exposure for NB in KFAS
+            if (length(unique(model$u[, i])) > 1)
+              stop(paste("Time-varying dispersion parameter for negative",
+                "binomial is not (yet) supported in 'bssm'.", sep = " "))
+            phi[i] <- model$u[1, i]
+            u[, i] <- 1 # no exposure for NB in KFAS
           }, 
           gaussian = {
-            if(length(unique(model$u[,i])) > 1)
-              stop("Time-varying standard deviation for gaussian distribution with non-gaussian series is not supported in 'bssm'.")
-            phi[i] <- sqrt(model$u[1,i])
-            u[,i] <- 1
+            if (length(unique(model$u[, i])) > 1)
+              stop(paste("Time-varying standard deviation for gaussian", 
+              "distribution with non-gaussian series is not supported",
+              "in 'bssm'.", sep = " "))
+            phi[i] <- sqrt(model$u[1, i])
+            u[, i] <- 1
           })
       }
       
@@ -121,8 +129,8 @@ as_bssm <- function(model, kappa = 100, ...) {
     
   } else {
     if (attr(model, "p") == 1) {
-      H = sqrt(c(model$H))
-      out <- ssm_ulg(y = model$y, Z =Z, H = H, T = model$T, R = R, 
+      out <- ssm_ulg(y = model$y, Z = Z, H = sqrt(c(model$H)), T = model$T, 
+        R = R, 
         a1 = c(model$a1), P1 = model$P1, state_names = rownames(model$a1), ...)
     } else {
       H <- model$H
@@ -140,4 +148,3 @@ as_bssm <- function(model, kappa = 100, ...) {
   
   out
 }
-
